@@ -1,11 +1,6 @@
 package MooseX::HasDefaults::Meta::IsRO;
 use Moose::Role;
 
-# This does not actually do anything but lie less in the attribute's metadata.
-has '+is' => (
-    default => 'ro',
-);
-
 around _process_options => sub {
     my $orig = shift;
     my (undef, undef, $options) = @_;
